@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "progressstatusbarwidget.h"
 
-#include "statusbarprogresswidget.h"
 #include "progressdialog.h"
+#include "statusbarprogresswidget.h"
 
 using namespace KPIM;
 class KPIM::ProgressStatusBarWidgetPrivate
@@ -23,7 +23,7 @@ ProgressStatusBarWidget::ProgressStatusBarWidget(QWidget *alignWidget, QWidget *
     : QObject(parent)
     , d(new KPIM::ProgressStatusBarWidgetPrivate)
 {
-    auto *progressDialog = new KPIM::ProgressDialog(alignWidget, parent);
+    auto progressDialog = new KPIM::ProgressDialog(alignWidget, parent);
     progressDialog->setObjectName(QStringLiteral("progressDialog"));
     progressDialog->setShowTypeProgressItem(showTypeProgressItem);
     progressDialog->hide();
