@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef STATUSBARPROGRESSWIDGET_GUI_H
-#define STATUSBARPROGRESSWIDGET_GUI_H
+#pragma once
 
 #include <QWidget>
 
@@ -17,4 +16,3 @@ public:
     ~StatusbarProgressWidget_Gui() = default;
 };
 
-#endif // STATUSBARPROGRESSWIDGET_GUI_H
